=================
Python Utilities for Cytoscape and Cytoscape.js
=================

What is py2cytoscape?
=================

This package is a collection of utilities to use Cytoscape and Cytoscape.js via cy-rest REST API app.
This is still experimental and in alpha status.

The following libraries will be supported:

* NetworkX
* igraph
* GraphLab

Note that this library is still in alpha status.